@@ -16,7 +16,7 @@
 #define vtk_gl2ps_h
 
 /* Use the gl2ps library configured for VTK.  */
-#define VTK_USE_SYSTEM_GL2PS
+/* #undef VTK_USE_SYSTEM_GL2PS */
 #ifdef VTK_USE_SYSTEM_GL2PS
 # include <gl2ps.h>
 #else
